<!-- !split -->
<!-- jupyter-book 04_09_testdoc.md -->
# Example: Just an example

<!-- This example needs the --examples_as_exercises option, otherwise -->
<!-- it is just typeset as it is written. -->

!bsubex
What is the capital of Norway?

!bans
Oslo.
!eans
!esubex

